#!/opt/LifeKeeper/bin/perl
# Copyright (c) 2020, 2022 SIOS Technology Corp.
########################################################################
#
# Title:       remove for Load Balancer probe reply
#
#
# Description: This script is called by the LifeKeeper core when a resource is
#              being taken out of service.  This could have been caused by a
#              manual "out of service" operation.
#
# Usage:    remove -t tagname -i id
#
#           where:
#           "tagname" is the resource tag name
#           "id" is the resource ID
#

use strict;
use Getopt::Std; # use the standard getopt package
BEGIN { require '/etc/default/LifeKeeper.pl'; } # use the LifeKeeper libraries
use LK;
use LKBase;
use vars qw($opt_t $opt_i);

my $thisCMD=`basename $0`;
chomp $thisCMD;
my $userinfo;
my $tag;
my $id;

sub parseOptions { # noparams

	getopts('t:i:');
	$tag = "$opt_t";
	$id = "$opt_i";
};

sub getInfo { # params: tag 

	my $tag = shift;
	@_ = LK::ins_list('', '', '', '', $tag, '');
	if ( @_ == 0 ){
		printf STDERR "$thisCMD: Internal error ins_list failed\n";
		exit 1;
	}
	@_ = split /\001/, $_[0];
	return ($_[5]);
};

#############################
# Main execution begins here
#############################

# parse command line options
parseOptions;

# $tag and $id are set now if they were given on the command line
($userinfo)=getInfo($tag);

# Check if daemon is running.
my $pidfile = "$ENV{'LKROOT'}/config/$id.pid";
my $pid;
if(open(my $PID, "< $pidfile")) {
	$pid=<$PID>;
	close($PID);
	#
	# $perl expects to include full path of perl command like /opt/LifeKeeper/bin/perl.
	# $cmd expects to include the full path of Gen-LB restore script like
	# /opt/LifeKeeper/subsys/gen/resources/app/actions/!restore/$tag.
	#
	my ($perl, $cmd) = split / /, `ps $pid | awk '{if (\$1 == "$pid") print \$5, \$6}'`;
	if (! defined $perl || $perl !~ /\/perl$/ || ! defined $cmd || $cmd !~/restore\/$tag$/) {
		LKBase::LogMsg({'STDERR' => 1}, LK::LK_INFO, "gen-lb", "remove", $tag, 127008, "Daemon not started.");
		exit 0;
	}
}
kill 'TERM', $pid;
unlink $pidfile;

exit 0;
